<?php
header('Content-Type: application/json');
require_once 'config.php';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $ad_soyad = mysqli_real_escape_string($conn, $_POST['ad_soyad']);
    $tc = mysqli_real_escape_string($conn, $_POST['tc']);
    $telefon = mysqli_real_escape_string($conn, $_POST['telefon']);
    $okul_adi = mysqli_real_escape_string($conn, $_POST['okul_adi']);
    $sinif = mysqli_real_escape_string($conn, $_POST['sinif']);

    // TC Kimlik Numarası Doğrulama
    function tcKimlikDogrula($tc) {
        if (strlen($tc) != 11) return false;
        if (!ctype_digit($tc)) return false;
        if ($tc[0] == '0') return false;

        $tek = 0;
        $cift = 0;
        $toplam = 0;
        $digit10 = 0;
        $digit11 = 0;

        for ($i = 0; $i < 9; $i += 2) {
            $tek += $tc[$i];
        }
        for ($i = 1; $i < 8; $i += 2) {
            $cift += $tc[$i];
        }

        $digit10 = (($tek * 7) - $cift) % 10;
        $toplam = 0;
        for ($i = 0; $i < 9; $i++) {
            $toplam += $tc[$i];
        }
        $digit11 = ($toplam + $digit10) % 10;

        return ($digit10 == $tc[9] && $digit11 == $tc[10]);
    }

    // Telefon numarası formatını kontrol et
    if (!preg_match("/^05[0-9]{9}$/", $telefon)) {
        echo json_encode(['success' => false, 'message' => 'Geçersiz telefon numarası formatı. Örnek: 05XXXXXXXXX']);
        exit;
    }

    // TC Kimlik kontrolü
    if (!tcKimlikDogrula($tc)) {
        echo json_encode(['success' => false, 'message' => 'Geçersiz TC Kimlik Numarası']);
        exit;
    }

    // Daha önce başvuru yapılmış mı kontrol et
    $sql = "SELECT * FROM basvurular WHERE telefon = '$telefon' OR tc = '$tc'";
    $result = mysqli_query($conn, $sql);
    
    if (mysqli_num_rows($result) > 0) {
        $row = mysqli_fetch_assoc($result);
        if ($row['telefon'] == $telefon) {
            echo json_encode(['success' => false, 'message' => 'Bu telefon numarası ile daha önce başvuru yapılmış']);
        } else {
            echo json_encode(['success' => false, 'message' => 'Bu TC Kimlik Numarası ile daha önce başvuru yapılmış']);
        }
        exit;
    }
    
    // Onay kodu oluştur
    $onay_kodu = sprintf("%06d", mt_rand(0, 999999));
    
    // Veritabanına kaydet
    $sql = "INSERT INTO basvurular (ad_soyad, tc, telefon, okul_adi, sinif, onay_kodu) 
            VALUES ('$ad_soyad', '$tc', '$telefon', '$okul_adi', '$sinif', '$onay_kodu')";
    
    if (mysqli_query($conn, $sql)) {
        // SMS şablonunu al
        $sql = "SELECT mesaj FROM sms_sablonlari WHERE tip = 'onay_kodu'";
        $result = mysqli_query($conn, $sql);
        $row = mysqli_fetch_assoc($result);
        $mesaj = $row['mesaj'];
        
        // Şablondaki değişkenleri değiştir
        $mesaj = str_replace('{AD_SOYAD}', $ad_soyad, $mesaj);
        $mesaj = str_replace('{ONAY_KODU}', $onay_kodu, $mesaj);
        
        // NetGSM API ile SMS gönder
        $url = "https://api.netgsm.com.tr/sms/send/get";
        $params = array(
            'usercode' => NETGSM_USERCODE,
            'password' => NETGSM_PASSWORD,
            'gsmno' => $telefon,
            'message' => $mesaj,
            'msgheader' => NETGSM_HEADER
        );
        
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url . '?' . http_build_query($params));
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        $response = curl_exec($ch);
        curl_close($ch);
        
        if ($response) {
            echo json_encode(['success' => true]);
        } else {
            echo json_encode(['success' => false, 'message' => 'SMS gönderilemedi']);
        }
    } else {
        echo json_encode(['success' => false, 'message' => 'Veritabanı hatası']);
    }
}
?>
